/*
  Control a SSD1320 based flexible OLED display
  By: Nathan Seidle
  SparkFun Electronics
  Date: November 21st, 2017
  License: This code is public domain but you buy me a beer if you use this and we meet someday (Beerware license).

  To connect the display to an Arduino:
  (Arduino pin) = (Display pin)
  Pin 13 = SCLK on carrier
  11 = SDIN
  10 = !CS
  8 = !RES

  The display is 160 pixels long and 32 pixels wide
  Each 4-bit nibble is the 4-bit grayscale for that pixel
  Therefore each byte of data written to the display paints two sequential pixels
  Loops that write to the display should be 80 iterations wide and 32 iterations tall
*/

#include "SSD1320_OLED.h"

//Initialize the display with the follow pin connections
SSD1320 oled(10, 9, 13, 11); //CS, RES, SCLK, MOSI(SDIN on OLED board)

void setup()
{
  Serial.begin(115200);

  oled.begin();

  oled.clearDisplay(); //Clear display RAM and local display buffer

  oled.setPixel(0, 0, WHITE, NORM);
  oled.setPixel(0, 31, WHITE, NORM);
  oled.setPixel(159, 0, WHITE, NORM);
  oled.setPixel(159, 31, WHITE, NORM);

  oled.setFontType(1);
  oled.setCursor(20, 12);
  oled.print("Hello World!");

  oled.setFontType(0);
  oled.setCursor(25, 0);
  oled.print("8:45:03 AM");

  oled.display();
}

void loop()
{

}





